@@ -1,11 +1,22 @@
 # -*- coding: utf-8 -*-
 '''stuf iterables.'''
 
+from functools import partial
 from itertools import starmap
 
 from stuf.six import items, map, next
 
 
+def _xhaust(call, iterable, exception=StopIteration, n=next, map=map):
+    '''Call function `call` on an `iterable` until it's exhausted.'''
+    iterable = map(call, iterable)
+    try:
+        while 1:
+            n(iterable)
+    except exception:
+        pass
+
+
 def breakcount(call, length):
     '''Call function `call` until it reaches its original `length`.'''
     while length:
@@ -46,27 +57,29 @@ def exhaust(iterable, exception=StopIteration, _n=next):
         pass
 
 
-def exhaustmap(mapping, call, filter=None, exception=StopIteration, _n=next):
+def exhaustmap(call, mapping, filter=None, exception=StopIteration, _n=next):
     '''Call `call` with optional `filter` on a `mapping` until exhausted.'''
-    exhaust(starmap(
+    iterable = starmap(
         call,
         items(mapping) if filter is None else filter(filter, items(mapping)),
-    ), exception)
+    )
+    try:
+        while 1:
+            _n(iterable)
+    except exception:
+        pass
 
 
-def exhaustcall(call, iterable, exception=StopIteration, _n=next, map=map):
-    '''Call function `call` on an `iterable` until it's exhausted.'''
-    exhaust(map(call, iterable), exception)
-
-
-def exhauststar(call, iterable, exception=StopIteration, _n=next, map=starmap):
-    '''Call function `call` on an `iterable` until it's exhausted.'''
-    exhaust(map(call, iterable), exception)
+def gauntlet(throws, this):
+    '''Run sequence of callables in `thrown` on `this` object.'''
+    for thrown in throws:
+        this = thrown(this)
+    return this
 
 
 def iterexcept(call, exception, start=None):
     '''
-    Call function `call` repeatedly until `exception` is raised.
+    Call function `call` until `exception` is raised.
 
     from Raymond Hettinger Python Cookbook recipe # 577155
     '''
@@ -77,3 +90,21 @@ def iterexcept(call, exception, start=None):
             yield call()
     except exception:
         pass
+
+
+partmap = partial(
+    lambda m, p, c, d, *a, **k: m(p(c, *a, **k), d), map, partial,
+)
+exhaustcall = partial(_xhaust, map=map)
+exhauststar = partial(_xhaust, map=starmap)
+xpartmap = partial(
+    lambda x, b, c, d, *a, **k: x(b(c, *a, **k), d), exhaustcall, partial,
+)
+xpartstar = partial(
+    lambda x, b, c, d, *a, **k: x(b(c, *a, **k), d), exhauststar, partial,
+)
+xpartitems = partial(
+    lambda x, p, c, i, f=None, *a, **k: x(p(c, *a, **k), i, f),
+    exhaustmap,
+    partial,
+)
